@@ -1,11 +1,11 @@
 /*
  *
- * Copyright (C) 2019-2021 Intel Corporation
+ * Copyright (C) 2019-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  * @file zet_ddi.h
- * @version v1.11-r1.11.5
+ * @version v1.15-r1.15.26
  *
  */
 #ifndef _ZET_DDI_H
@@ -281,12 +281,26 @@ typedef ze_result_t (ZE_APICALL *zet_pfnDeviceCreateMetricGroupsFromMetricsExp_t
     zet_metric_group_handle_t*
     );
 
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zetDeviceEnableMetricsExp 
+typedef ze_result_t (ZE_APICALL *zet_pfnDeviceEnableMetricsExp_t)(
+    zet_device_handle_t
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zetDeviceDisableMetricsExp 
+typedef ze_result_t (ZE_APICALL *zet_pfnDeviceDisableMetricsExp_t)(
+    zet_device_handle_t
+    );
+
 ///////////////////////////////////////////////////////////////////////////////
 /// @brief Table of DeviceExp functions pointers
 typedef struct _zet_device_exp_dditable_t
 {
     zet_pfnDeviceGetConcurrentMetricGroupsExp_t                 pfnGetConcurrentMetricGroupsExp;
     zet_pfnDeviceCreateMetricGroupsFromMetricsExp_t             pfnCreateMetricGroupsFromMetricsExp;
+    zet_pfnDeviceEnableMetricsExp_t                             pfnEnableMetricsExp;
+    zet_pfnDeviceDisableMetricsExp_t                            pfnDisableMetricsExp;
 } zet_device_exp_dditable_t;
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -412,6 +426,43 @@ typedef ze_result_t (ZE_APICALL *zet_pfnGetCommandListProcAddrTable_t)(
     zet_command_list_dditable_t*
     );
 
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zetCommandListAppendMarkerExp 
+typedef ze_result_t (ZE_APICALL *zet_pfnCommandListAppendMarkerExp_t)(
+    zet_command_list_handle_t,
+    zet_metric_group_handle_t,
+    uint32_t
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Table of CommandListExp functions pointers
+typedef struct _zet_command_list_exp_dditable_t
+{
+    zet_pfnCommandListAppendMarkerExp_t                         pfnAppendMarkerExp;
+} zet_command_list_exp_dditable_t;
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Exported function for filling application's CommandListExp table
+///        with current process' addresses
+///
+/// @returns
+///     - ::ZE_RESULT_SUCCESS
+///     - ::ZE_RESULT_ERROR_UNINITIALIZED
+///     - ::ZE_RESULT_ERROR_INVALID_NULL_POINTER
+///     - ::ZE_RESULT_ERROR_UNSUPPORTED_VERSION
+ZE_DLLEXPORT ze_result_t ZE_APICALL
+zetGetCommandListExpProcAddrTable(
+    ze_api_version_t version,                                               ///< [in] API version requested
+    zet_command_list_exp_dditable_t* pDdiTable                              ///< [in,out] pointer to table of DDI function pointers
+    );
+
+///////////////////////////////////////////////////////////////////////////////
+/// @brief Function-pointer for zetGetCommandListExpProcAddrTable
+typedef ze_result_t (ZE_APICALL *zet_pfnGetCommandListExpProcAddrTable_t)(
+    ze_api_version_t,
+    zet_command_list_exp_dditable_t*
+    );
+
 ///////////////////////////////////////////////////////////////////////////////
 /// @brief Function-pointer for zetModuleGetDebugInfo 
 typedef ze_result_t (ZE_APICALL *zet_pfnModuleGetDebugInfo_t)(
@@ -1154,6 +1205,7 @@ typedef struct _zet_dditable_t
     zet_device_exp_dditable_t           DeviceExp;
     zet_context_dditable_t              Context;
     zet_command_list_dditable_t         CommandList;
+    zet_command_list_exp_dditable_t     CommandListExp;
     zet_module_dditable_t               Module;
     zet_kernel_dditable_t               Kernel;
     zet_metric_dditable_t               Metric;
@@ -1166,6 +1218,31 @@ typedef struct _zet_dditable_t
     zet_tracer_exp_dditable_t           TracerExp;
     zet_debug_dditable_t                Debug;
 } zet_dditable_t;
+/// @brief Container for all DDI tables with version and tables set by the Driver
+typedef struct _zet_dditable_driver_t
+{
+    ze_api_version_t    version;
+    uint8_t             isValidFlag;
+    zet_metric_programmable_exp_dditable_t *    MetricProgrammableExp;
+    zet_metric_tracer_exp_dditable_t *  MetricTracerExp;
+    zet_metric_decoder_exp_dditable_t * MetricDecoderExp;
+    zet_device_dditable_t *             Device;
+    zet_device_exp_dditable_t *         DeviceExp;
+    zet_context_dditable_t *            Context;
+    zet_command_list_dditable_t *       CommandList;
+    zet_command_list_exp_dditable_t *   CommandListExp;
+    zet_module_dditable_t *             Module;
+    zet_kernel_dditable_t *             Kernel;
+    zet_metric_dditable_t *             Metric;
+    zet_metric_exp_dditable_t *         MetricExp;
+    zet_metric_group_dditable_t *       MetricGroup;
+    zet_metric_group_exp_dditable_t *   MetricGroupExp;
+    zet_metric_streamer_dditable_t *    MetricStreamer;
+    zet_metric_query_pool_dditable_t *  MetricQueryPool;
+    zet_metric_query_dditable_t *       MetricQuery;
+    zet_tracer_exp_dditable_t *         TracerExp;
+    zet_debug_dditable_t *              Debug;
+} zet_dditable_driver_t;
 
 #if defined(__cplusplus)
 } // extern "C"
